@@ -4,7 +4,7 @@ use Carp ();
 ############################################################################
 package Net::OpenID::VerifiedIdentity;
 BEGIN {
-  $Net::OpenID::VerifiedIdentity::VERSION = '1.12';
+  $Net::OpenID::VerifiedIdentity::VERSION = '1.13';
 }
 use fields (
     'identity',  # the verified identity URL
@@ -278,7 +278,7 @@ Net::OpenID::VerifiedIdentity - Object representing a verified OpenID identity
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 SYNOPSIS
 
@@ -391,4 +391,4 @@ L<Net::OpenID::ClaimedIdentity>
 
 L<Net::OpenID::Server>
 
-Website:  L<http://www.danga.com/openid/>
\ No newline at end of file
+Website:  L<http://openid.net/>
\ No newline at end of file
